This tibble contains city, state, latitude, and longitude for U.S. ZIP codes from the CivicSpace Database (August 2004) augmented by Daniel Coven's web site (updated on January 22, 2012). The data was originally contained in the zipcode CRAN package, which was archived on January 1, 2020.

zipcodes

Format

A tibble with 44,336 rows and 5 variables:

zip

5 digit ZIP code or military postal code (FPO/APO)

city

USPS official city name

state

USPS official state, territory abbreviation code

lat

Decimal latitude

long

Decimal longitude

Daniel Coven's web site and the CivicSpace US ZIP Code Database written by Schuyler Erle schuyler@geocoder.us, 5 August 2004.