state_centers: US State Geographic Centers

state_centersR Documentation

US State Geographic Centers

Description

A list with components named x and y giving the approximate geographic centroid of each state in longitude and latitude. Parallel to state_names.

Usage

state_centers

Format

A list of length two, each element a numeric vector of length 51.

x

Centroid longitudinal coordinate

y

Centroid latitudinal coordinate

TIGER/Web REST API (State_County layer)


usa documentation built on May 14, 2026, 5:08 p.m.