| state_centers | R Documentation |
A list with components named x and y giving the approximate geographic
centroid of each state in longitude and latitude. Parallel to state_names.
state_centers
A list of length two, each element a numeric vector of length 51.
Centroid longitudinal coordinate
Centroid latitudinal coordinate
TIGER/Web REST API (State_County layer)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.