territory_centers: US Territory Geographic Centers

territory_centersR Documentation

US Territory Geographic Centers

Description

A list with components named x and y giving the approximate geographic center of each territory in longitude and latitude.

Usage

territory_centers

Format

A list of length two, each element a numeric vector of length 6.

x

Center longitudinal coordinate

y

Center latitudinal coordinate

TIGER/Web REST API (State_County layer)


usa documentation built on May 14, 2026, 5:08 p.m.