| territory_centers | R Documentation |
A list with components named x and y giving the approximate geographic
center of each territory in longitude and latitude.
territory_centers
A list of length two, each element a numeric vector of length 6.
Center longitudinal coordinate
Center latitudinal coordinate
TIGER/Web REST API (State_County layer)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.